package jp.ne.motoki.android.hellolivewallpaper;


import static jp.ne.motoki.android.hellolivewallpaper.Utils.log_debug;
import android.service.wallpaper.WallpaperService;
import android.view.SurfaceHolder;

public class HelloWallpaperService extends WallpaperService {

    @Override
	public Engine onCreateEngine() {
		log_debug("onCreateEngine");
		return new HelloEffectEngine();
	}

	public class HelloEffectEngine extends Engine {

        private GLEngineSurface gl = null;

		@Override
		public void onCreate(SurfaceHolder surfaceHolder) {
			log_debug("onCreate");
			super.onCreate(surfaceHolder);
			surfaceHolder.setType(SurfaceHolder.SURFACE_TYPE_GPU);
		}

		@Override
		public void onSurfaceChanged(
				SurfaceHolder holder, int format, int width, int height) {
			log_debug(String.format(
					"onSurfaceChanged: format = %d, width = %d, height = %d",
					format, width, height));
			super.onSurfaceChanged(holder, format, width, height);
			
			gl.windowWidth = width;
			gl.windowHeight = height;
		}

		@Override
		public void onSurfaceCreated(SurfaceHolder holder) {
			log_debug("onSurfaceCreated");
			super.onSurfaceCreated(holder);
            
            gl  = new GLEngineSurface(
                    HelloWallpaperService.this, getSurfaceHolder());
            gl.start();
		}

		@Override
		public void onSurfaceDestroyed(SurfaceHolder holder) {
			super.onSurfaceDestroyed(holder);
			log_debug("onSurfaceDestroyed");
			
			if (gl != null) {
			    gl.onDestroy();
			    gl = null;
			}
		}

		@Override
		public void onDestroy() {
			log_debug("onDestroy");
			super.onDestroy();
		}
		
		@Override
		public void onVisibilityChanged(boolean visible) {
		    log_debug("onVisibilityChanged : " + visible);
		    super.onVisibilityChanged(visible);
		    
		    if (visible) {
		        gl.onResume();
		    } else {
		        gl.onPause();
		    }
		}
	}
}
